@@ -12,12 +12,14 @@ import os
 import sys
 
 from spyder.config.fonts import MEDIUM, MONOSPACE, SANS_SERIF, SMALL
+from spyder.plugins.help.utils.sphinxify import CSS_PATH
 
 WIN = os.name == 'nt'
 LINUX = sys.platform.startswith('openbsd')
 
 # Default themes
 APPEARANCE = {
+    'css_path': CSS_PATH,
     'icon_theme': 'spyder 3',
     # Global Spyder fonts
     'font/family': MONOSPACE,
@@ -41,7 +43,7 @@ APPEARANCE = {
     'emacs/background':  "#000000",
     'emacs/currentline': "#2b2b43",
     'emacs/currentcell': "#1c1c2d",
-    'emacs/occurrence':   "#63a4cf",
+    'emacs/occurrence':  "#1A72BB",
     'emacs/ctrlclick':   "#0000ff",
     'emacs/sideareas':   "#555555",
     'emacs/matched_p':   "#009800",
@@ -61,7 +63,7 @@ APPEARANCE = {
     'idle/background':   "#ffffff",
     'idle/currentline':  "#f2e6f3",
     'idle/currentcell':  "#feefff",
-    'idle/occurrence':    "#b381b8",
+    'idle/occurrence':   "#C2E3FA",
     'idle/ctrlclick':    "#0000ff",
     'idle/sideareas':    "#efefef",
     'idle/matched_p':    "#99ff99",
@@ -81,7 +83,7 @@ APPEARANCE = {
     'monokai/background':   "#2a2b24",
     'monokai/currentline':  "#484848",
     'monokai/currentcell':  "#3d3d3d",
-    'monokai/occurrence':    "#f081dd",
+    'monokai/occurrence':   "#1A72BB",
     'monokai/ctrlclick':    "#0000ff",
     'monokai/sideareas':    "#2a2b24",
     'monokai/matched_p':    "#688060",
@@ -101,7 +103,7 @@ APPEARANCE = {
     'pydev/background':  "#ffffff",
     'pydev/currentline': "#e8f2fe",
     'pydev/currentcell': "#eff8fe",
-    'pydev/occurrence':   "#ffff99",
+    'pydev/occurrence':  "#C2E3FA",
     'pydev/ctrlclick':   "#0000ff",
     'pydev/sideareas':   "#efefef",
     'pydev/matched_p':   "#99ff99",
@@ -121,7 +123,7 @@ APPEARANCE = {
     'scintilla/background':  "#ffffff",
     'scintilla/currentline': "#e1f0d1",
     'scintilla/currentcell': "#edfcdc",
-    'scintilla/occurrence':   "#ffff99",
+    'scintilla/occurrence':  "#C2E3FA",
     'scintilla/ctrlclick':   "#0000ff",
     'scintilla/sideareas':   "#efefef",
     'scintilla/matched_p':   "#99ff99",
@@ -141,7 +143,7 @@ APPEARANCE = {
     'spyder/background':  "#ffffff",
     'spyder/currentline': "#f7ecf8",
     'spyder/currentcell': "#fdfdde",
-    'spyder/occurrence':   "#ffff99",
+    'spyder/occurrence':  "#C2E3FA",
     'spyder/ctrlclick':   "#0000ff",
     'spyder/sideareas':   "#efefef",
     'spyder/matched_p':   "#99ff99",
@@ -161,7 +163,7 @@ APPEARANCE = {
     'spyder/dark/background':  "#19232D",
     'spyder/dark/currentline': "#3a424a",
     'spyder/dark/currentcell': "#292d3e",
-    'spyder/dark/occurrence':  "#4734b3",
+    'spyder/dark/occurrence':  "#1A72BB",
     'spyder/dark/ctrlclick':   "#179ae0",
     'spyder/dark/sideareas':   "#222b35",
     'spyder/dark/matched_p':   "#0bbe0b",
@@ -181,7 +183,7 @@ APPEARANCE = {
     'zenburn/background':  "#3f3f3f",
     'zenburn/currentline': "#333333",
     'zenburn/currentcell': "#2c2c2c",
-    'zenburn/occurrence':   "#7a738f",
+    'zenburn/occurrence':  "#1A72BB",
     'zenburn/ctrlclick':   "#0000ff",
     'zenburn/sideareas':   "#3f3f3f",
     'zenburn/matched_p':   "#688060",
@@ -201,7 +203,7 @@ APPEARANCE = {
     'solarized/light/background':  '#fdf6e3',
     'solarized/light/currentline': '#f5efdB',
     'solarized/light/currentcell': '#eee8d5',
-    'solarized/light/occurrence':  '#9ed2de',
+    'solarized/light/occurrence':  '#C2E3FA',
     'solarized/light/ctrlclick':   '#d33682',
     'solarized/light/sideareas':   '#eee8d5',
     'solarized/light/matched_p':   '#d6dabf',
@@ -221,12 +223,12 @@ APPEARANCE = {
     'solarized/dark/background':  '#002b36',
     'solarized/dark/currentline': '#083f4d',
     'solarized/dark/currentcell': '#073642',
-    'solarized/dark/occurrence':  '#180936',
+    'solarized/dark/occurrence':  '#1A72BB',
     'solarized/dark/ctrlclick':   '#d33682',
     'solarized/dark/sideareas':   '#073642',
     'solarized/dark/matched_p':   '#586e75',
     'solarized/dark/unmatched_p': '#dc322f',
-    'solarized/dark/normal':     ('#839496', False, False),
+    'solarized/dark/normal':     ('#E1E1E1', False, False),
     'solarized/dark/keyword':    ('#859900', False, False),
     'solarized/dark/magic':      ('#859900', False, False),
     'solarized/dark/builtin':    ('#6c71c4', False, False),
@@ -241,7 +243,7 @@ APPEARANCE = {
     'inkpot/background':  "#1f1f27",
     'inkpot/currentline': "#2d2d44",
     'inkpot/currentcell': "#33333A",
-    'inkpot/occurrence':  "#616161",
+    'inkpot/occurrence':  "#1A72BB",
     'inkpot/ctrlclick':   "#1f1f27",
     'inkpot/sideareas':   "#2d2d44",
     'inkpot/matched_p':   "#3672b5",
@@ -261,7 +263,7 @@ APPEARANCE = {
     'minimal/background':  "#ffffff",
     'minimal/currentline': "#aaccff",
     'minimal/currentcell': "#E7F1FF",
-    'minimal/occurrence':  "#9888b8",
+    'minimal/occurrence':  "#C2E3FA",
     'minimal/ctrlclick':   "#05314d",
     'minimal/sideareas':   "#aaccff",
     'minimal/matched_p':   "#000000",
@@ -281,7 +283,7 @@ APPEARANCE = {
     'nightlion/background':  "#1e1e1e",
     'nightlion/currentline': "#505050",
     'nightlion/currentcell': "#323232",
-    'nightlion/occurrence':  "#616161",
+    'nightlion/occurrence':  "#1A72BB",
     'nightlion/ctrlclick':   "#b3b5af",
     'nightlion/sideareas':   "#505050",
     'nightlion/matched_p':   "#3672b5",
@@ -301,7 +303,7 @@ APPEARANCE = {
     'notepad++/background':  "#ffffff",
     'notepad++/currentline': "#eeeeee",
     'notepad++/currentcell': "#D9D9D9",
-    'notepad++/occurrence':  "#abbcd9",
+    'notepad++/occurrence':  "#C2E3FA",
     'notepad++/ctrlclick':   "#800080",
     'notepad++/sideareas':   "#eeeeee",
     'notepad++/matched_p':   "#8000ff",
@@ -321,7 +323,7 @@ APPEARANCE = {
     'oblivion/background':  "#1e1e1e",
     'oblivion/currentline': "#2a2a2a",
     'oblivion/currentcell': "#323232",
-    'oblivion/occurrence':  "#060b47",
+    'oblivion/occurrence':  "#1A72BB",
     'oblivion/ctrlclick':   "#ccdf32",
     'oblivion/sideareas':   "#2a2a2a",
     'oblivion/matched_p':   "#de7878",
@@ -341,7 +343,7 @@ APPEARANCE = {
     'obsidian/background':  "#293134",
     'obsidian/currentline': "#2f393c",
     'obsidian/currentcell': "#3C4346",
-    'obsidian/occurrence':  "#e0de43",
+    'obsidian/occurrence':  "#1A72BB",
     'obsidian/ctrlclick':   "#7d8c93",
     'obsidian/sideareas':   "#2f393c",
     'obsidian/matched_p':   "#3672b5",
@@ -361,7 +363,7 @@ APPEARANCE = {
     'pastel/background':  "#1f2223",
     'pastel/currentline': "#2f393c",
     'pastel/currentcell': "#454849",
-    'pastel/occurrence':  "#edcd79",
+    'pastel/occurrence':  "#1A72BB",
     'pastel/ctrlclick':   "#7d8c93",
     'pastel/sideareas':   "#2f393c",
     'pastel/matched_p':   "#3672b5",
@@ -381,7 +383,7 @@ APPEARANCE = {
     'retta/background':  "#000000",
     'retta/currentline': "#2a2a2a",
     'retta/currentcell': "#171717",
-    'retta/occurrence':  "#5e5c56",
+    'retta/occurrence':  "#1A72BB",
     'retta/ctrlclick':   "#83786e",
     'retta/sideareas':   "#2a2a2a",
     'retta/matched_p':   "#de7878",
@@ -401,7 +403,7 @@ APPEARANCE = {
     'roboticket/background':  "#f5f5f5",
     'roboticket/currentline': "#e0e0ff",
     'roboticket/currentcell': "#CCCCE8",
-    'roboticket/occurrence':  "#ffcfbb",
+    'roboticket/occurrence':  "#C2E3FA",
     'roboticket/ctrlclick':   "#ad95af",
     'roboticket/sideareas':   "#e0e0ff",
     'roboticket/matched_p':   "#585858",
@@ -421,7 +423,7 @@ APPEARANCE = {
     'sublime-monokai/extended/background':  "#222222",
     'sublime-monokai/extended/currentline': "#2f2f2f",
     'sublime-monokai/extended/currentcell': "#363636",
-    'sublime-monokai/extended/occurrence':  "#f081dd",
+    'sublime-monokai/extended/occurrence':  "#1A72BB",
     'sublime-monokai/extended/ctrlclick':   "#ffffff",
     'sublime-monokai/extended/sideareas':   "#2f2f2f",
     'sublime-monokai/extended/matched_p':   "#679116",
@@ -441,7 +443,7 @@ APPEARANCE = {
     'vibrant-ink/background':  "#191919",
     'vibrant-ink/currentline': "#222220",
     'vibrant-ink/currentcell': "#2D2D2D",
-    'vibrant-ink/occurrence':  "#d97a43",
+    'vibrant-ink/occurrence':  "#1A72BB",
     'vibrant-ink/ctrlclick':   "#8c3fc8",
     'vibrant-ink/sideareas':   "#222220",
     'vibrant-ink/matched_p':   "#598c19",
