@@ -25,19 +25,20 @@ from qtpy.QtWidgets import QApplication, QMainWindow, QPlainTextEdit, QToolTip
 # Local imports
 from spyder.config.gui import get_font
 from spyder.config.manager import CONF
-from spyder.py3compat import PY3, to_text_string
-from spyder.widgets.calltip import CallTipWidget, ToolTipWidget
-from spyder.widgets.mixins import BaseEditMixin
 from spyder.plugins.editor.api.decoration import TextDecoration, DRAW_ORDERS
 from spyder.plugins.editor.utils.decoration import TextDecorationsManager
 from spyder.plugins.editor.widgets.completion import CompletionWidget
+from spyder.plugins.completion.api import CompletionItemKind
 from spyder.plugins.outlineexplorer.api import is_cell_header, document_cells
+from spyder.py3compat import to_text_string
+from spyder.utils.palette import SpyderPalette
+from spyder.widgets.calltip import CallTipWidget, ToolTipWidget
+from spyder.widgets.mixins import BaseEditMixin
 
 
 class TextEditBaseWidget(QPlainTextEdit, BaseEditMixin):
     """Text edit base widget"""
     BRACE_MATCHING_SCOPE = ('sof', 'eof')
-    has_cell_separators = False
     focus_in = Signal()
     zoom_in = Signal()
     zoom_out = Signal()
@@ -45,13 +46,16 @@ class TextEditBaseWidget(QPlainTextEdit, BaseEditMixin):
     focus_changed = Signal()
     sig_insert_completion = Signal(str)
     sig_eol_chars_changed = Signal(str)
+    sig_prev_cursor = Signal()
+    sig_next_cursor = Signal()
 
     def __init__(self, parent=None):
         QPlainTextEdit.__init__(self, parent)
         BaseEditMixin.__init__(self)
+
+        self.has_cell_separators = False
         self.setAttribute(Qt.WA_DeleteOnClose)
 
-        self.extra_selections_dict = {}
         self._restore_selection_pos = None
 
         # Trailing newlines/spaces trimming
@@ -64,7 +68,6 @@ class TextEditBaseWidget(QPlainTextEdit, BaseEditMixin):
         # Code snippets
         self.code_snippets = True
 
-        self.textChanged.connect(self.changed)
         self.cursorPositionChanged.connect(self.cursor_position_changed)
 
         self.indent_chars = " "*4
@@ -85,20 +88,21 @@ class TextEditBaseWidget(QPlainTextEdit, BaseEditMixin):
         self.setup_completion()
 
         self.calltip_widget = CallTipWidget(self, hide_timer_on=False)
-        self.calltip_position = None
         self.tooltip_widget = ToolTipWidget(self, as_tooltip=True)
 
         self.highlight_current_cell_enabled = False
 
         # The color values may be overridden by the syntax highlighter
         # Highlight current line color
-        self.currentline_color = QColor(Qt.red).lighter(190)
-        self.currentcell_color = QColor(Qt.red).lighter(194)
+        self.currentline_color = QColor(
+            SpyderPalette.COLOR_ERROR_2).lighter(190)
+        self.currentcell_color = QColor(
+            SpyderPalette.COLOR_ERROR_2).lighter(194)
 
         # Brace matching
         self.bracepos = None
-        self.matched_p_color = QColor(Qt.green)
-        self.unmatched_p_color = QColor(Qt.red)
+        self.matched_p_color = QColor(SpyderPalette.COLOR_SUCCESS_1)
+        self.unmatched_p_color = QColor(SpyderPalette.COLOR_ERROR_2)
 
         self.decorations = TextDecorationsManager(self)
 
@@ -108,9 +112,14 @@ class TextEditBaseWidget(QPlainTextEdit, BaseEditMixin):
 
         def reset_current_cell():
             self.current_cell = None
+            self.highlight_current_cell()
 
         self.textChanged.connect(reset_current_cell)
 
+        # Cache
+        self._current_cell_cursor = None
+        self._current_line_block = None
+
     def setup_completion(self):
         size = CONF.get('main', 'completion/size')
         font = get_font()
@@ -163,13 +172,13 @@ class TextEditBaseWidget(QPlainTextEdit, BaseEditMixin):
         Returns:
             list of sourcecode.api.TextDecoration.
         """
-        return self.extra_selections_dict.get(key, [])
+        return self.decorations.get(key, [])
 
     def set_extra_selections(self, key, extra_selections):
         """Set extra selections for a key.
 
         Also assign draw orders to leave current_cell and current_line
-        in the backgrund (and avoid them to cover other decorations)
+        in the background (and avoid them to cover other decorations)
 
         NOTE: This will remove previous decorations added to the same key.
 
@@ -186,20 +195,8 @@ class TextEditBaseWidget(QPlainTextEdit, BaseEditMixin):
             selection.draw_order = draw_order
             selection.kind = key
 
-        self.clear_extra_selections(key)
-        self.extra_selections_dict[key] = extra_selections
-
-    def update_extra_selections(self):
-        """Add extra selections to DecorationsManager.
-
-        TODO: This method could be remove it and decorations could be
-        added/removed in set_extra_selections/clear_extra_selections.
-        """
-        extra_selections = []
-
-        for key, extra in list(self.extra_selections_dict.items()):
-            extra_selections.extend(extra)
-        self.decorations.add(extra_selections)
+        self.decorations.add_key(key, extra_selections)
+        self.update()
 
     def clear_extra_selections(self, key):
         """Remove decorations added through set_extra_selections.
@@ -207,15 +204,9 @@ class TextEditBaseWidget(QPlainTextEdit, BaseEditMixin):
         Args:
             key (str) name of the extra selections group.
         """
-        for decoration in self.extra_selections_dict.get(key, []):
-            self.decorations.remove(decoration)
-        self.extra_selections_dict[key] = []
+        self.decorations.remove_key(key)
         self.update()
 
-    def changed(self):
-        """Emit changed signal"""
-        self.modificationChanged.emit(self.document().isModified())
-
     def get_visible_block_numbers(self):
         """Get the first and last visible block numbers."""
         first = self.firstVisibleBlock().blockNumber()
@@ -241,28 +232,47 @@ class TextEditBaseWidget(QPlainTextEdit, BaseEditMixin):
 
         return (first, last)
 
-    #------Highlight current line
+    # ------Highlight current line
     def highlight_current_line(self):
         """Highlight current line"""
-        selection = TextDecoration(self.textCursor())
+        cursor = self.textCursor()
+        block = cursor.block()
+        if self._current_line_block == block:
+            return
+        self._current_line_block = block
+        selection = TextDecoration(cursor)
         selection.format.setProperty(QTextFormat.FullWidthSelection,
                                      to_qvariant(True))
         selection.format.setBackground(self.currentline_color)
         selection.cursor.clearSelection()
         self.set_extra_selections('current_line', [selection])
-        self.update_extra_selections()
 
     def unhighlight_current_line(self):
         """Unhighlight current line"""
+        self._current_line_block = None
         self.clear_extra_selections('current_line')
 
-    #------Highlight current cell
+    # ------Highlight current cell
     def highlight_current_cell(self):
         """Highlight current cell"""
         if (not self.has_cell_separators or
                 not self.highlight_current_cell_enabled):
+            self._current_cell_cursor = None
             return
         cursor, whole_file_selected = self.select_current_cell()
+
+        def same_selection(c1, c2):
+            if c1 is None or c2 is None:
+                return False
+            return (
+                c1.selectionStart() == c2.selectionStart() and
+                c1.selectionEnd() == c2.selectionEnd()
+            )
+
+        if same_selection(self._current_cell_cursor, cursor):
+            # Already correct
+            return
+        self._current_cell_cursor = cursor
         selection = TextDecoration(cursor)
         selection.format.setProperty(QTextFormat.FullWidthSelection,
                                      to_qvariant(True))
@@ -272,10 +282,10 @@ class TextEditBaseWidget(QPlainTextEdit, BaseEditMixin):
             self.clear_extra_selections('current_cell')
         else:
             self.set_extra_selections('current_cell', [selection])
-            self.update_extra_selections()
 
     def unhighlight_current_cell(self):
         """Unhighlight current cell"""
+        self._current_cell_cursor = None
         self.clear_extra_selections('current_cell')
 
     def in_comment(self, cursor=None, position=None):
@@ -406,7 +416,6 @@ class TextEditBaseWidget(QPlainTextEdit, BaseEditMixin):
                                           QTextCursor.KeepAnchor)
             extra_selections.append(selection)
         self.set_extra_selections('brace_matching', extra_selections)
-        self.update_extra_selections()
 
     def cursor_position_changed(self):
         """Handle brace matching."""
@@ -442,11 +451,7 @@ class TextEditBaseWidget(QPlainTextEdit, BaseEditMixin):
             self.bracepos = (pos1,)
             self.__highlight(self.bracepos, color=self.unmatched_p_color)
 
-    #-----Widget setup and options
-    def set_codecompletion_auto(self, state):
-        """Set code completion state"""
-        self.codecompletion_auto = state
-
+    # -----Widget setup and options
     def set_wrap_mode(self, mode=None):
         """
         Set wrap mode
@@ -460,7 +465,7 @@ class TextEditBaseWidget(QPlainTextEdit, BaseEditMixin):
             wrap_mode = QTextOption.NoWrap
         self.setWordWrapMode(wrap_mode)
 
-    #------Reimplementing Qt methods
+    # ------Reimplementing Qt methods
     @Slot()
     def copy(self):
         """
@@ -480,15 +485,14 @@ class TextEditBaseWidget(QPlainTextEdit, BaseEditMixin):
         # corruptions when saving files with certain combinations
         # of unicode chars on them (like the one attached on
         # spyder-ide/spyder#1546).
-        if os.name == 'nt' and PY3:
+        if os.name == 'nt':
             text = self.get_text('sof', 'eof')
             return text.replace('\u2028', '\n').replace('\u2029', '\n')\
                        .replace('\u0085', '\n')
-        else:
-            return super(TextEditBaseWidget, self).toPlainText()
+        return super(TextEditBaseWidget, self).toPlainText()
 
     def keyPressEvent(self, event):
-        text, key = event.text(), event.key()
+        key = event.key()
         ctrl = event.modifiers() & Qt.ControlModifier
         meta = event.modifiers() & Qt.MetaModifier
         # Use our own copy method for {Ctrl,Cmd}+C to avoid Qt
@@ -498,7 +502,7 @@ class TextEditBaseWidget(QPlainTextEdit, BaseEditMixin):
         else:
             super(TextEditBaseWidget, self).keyPressEvent(event)
 
-    #------Text: get, set, ...
+    # ------Text: get, set, ...
     def get_cell_list(self):
         """Get all cells."""
         # Reimplemented in childrens
@@ -565,8 +569,8 @@ class TextEditBaseWidget(QPlainTextEdit, BaseEditMixin):
         if cursor is None:
             cursor = self.textCursor()
         ls = self.get_line_separator()
-        cursor, whole_file_selected = self.select_current_cell(cursor)
-        line_from, line_to = self.get_selection_bounds(cursor)
+        cursor, __ = self.select_current_cell(cursor)
+        line_from, __ = self.get_selection_bounds(cursor)
         # Get the block for the first cell line
         start = cursor.selectionStart()
         block = self.document().findBlock(start)
@@ -738,8 +742,6 @@ class TextEditBaseWidget(QPlainTextEdit, BaseEditMixin):
         cursor.insertText(text)
         cursor.endEditBlock()
 
-        self.document_did_change()
-
     def duplicate_line_down(self):
         """
         Copy current line or selected text and paste the duplicated text
@@ -829,8 +831,6 @@ class TextEditBaseWidget(QPlainTextEdit, BaseEditMixin):
         self.setTextCursor(cursor)
         self.__restore_selection(start_pos, end_pos)
 
-        self.document_did_change()
-
     def move_line_up(self):
         """Move up current line or selected text"""
         self.__move_line_or_selection(after_current_line=False)
@@ -878,7 +878,6 @@ class TextEditBaseWidget(QPlainTextEdit, BaseEditMixin):
         cursor.removeSelectedText()
         cursor.endEditBlock()
         self.ensureCursorVisible()
-        self.document_did_change()
 
     def set_selection(self, start, end):
         cursor = self.textCursor()
@@ -906,25 +905,14 @@ class TextEditBaseWidget(QPlainTextEdit, BaseEditMixin):
         if cursor_position < position_from or cursor_position > position_to:
             self.set_cursor_position(position_to)
 
-    #------Code completion / Calltips
-    def hide_tooltip_if_necessary(self, key):
-        """Hide calltip when necessary"""
-        try:
-            calltip_char = self.get_character(self.calltip_position)
-            before = self.is_cursor_before(self.calltip_position,
-                                           char_offset=1)
-            other = key in (Qt.Key_ParenRight, Qt.Key_Period, Qt.Key_Tab)
-            if calltip_char not in ('?', '(') or before or other:
-                QToolTip.hideText()
-        except (IndexError, TypeError):
-            QToolTip.hideText()
-
+    # ------Code completion / Calltips
     def select_completion_list(self):
         """Completion list is active, Enter was just pressed"""
         self.completion_widget.item_selected()
 
     def insert_completion(self, completion, completion_position):
-        """Insert a completion into the editor.
+        """
+        Insert a completion into the editor.
 
         completion_position is where the completion was generated.
 
@@ -952,25 +940,86 @@ class TextEditBaseWidget(QPlainTextEdit, BaseEditMixin):
                 end = self.get_position_line_number(end_line, end_col)
             cursor.setPosition(start)
             cursor.setPosition(end, QTextCursor.KeepAnchor)
-            text = to_text_string(completion['textEdit']['newText'])
+            text = str(completion['textEdit']['newText'])
         else:
             text = completion
+            kind = None
             if isinstance(completion, dict):
                 text = completion['insertText']
-            text = to_text_string(text)
+                kind = completion['kind']
+            text = str(text)
 
-            # Get word on the left of the cursor.
-            result = self.get_current_word_and_position(completion=True)
+            # Get word to the left of the cursor.
+            result = self.get_current_word_and_position(
+                completion=True, valid_python_variable=False)
             if result is not None:
                 current_text, start_position = result
                 end_position = start_position + len(current_text)
-                # Check if the completion position is in the expected range
-                if not start_position <= completion_position <= end_position:
-                    return
-                cursor.setPosition(start_position)
-                # Remove the word under the cursor
-                cursor.setPosition(end_position,
-                                   QTextCursor.KeepAnchor)
+
+                # Remove text under cursor only if it's not an autocompletion
+                # character
+                is_auto_completion_character = False
+                if self.objectName() == 'console':
+                    if current_text == '.':
+                        is_auto_completion_character = True
+                else:
+                    if (
+                        kind != CompletionItemKind.FILE and
+                        current_text in self.auto_completion_characters
+                    ):
+                        is_auto_completion_character = True
+
+                # Adjustments for file completions
+                if kind == CompletionItemKind.FILE:
+                    special_chars = ['"', "'", '/', '\\']
+
+                    if any(
+                        [current_text.endswith(c) for c in special_chars]
+                    ):
+                        # This is necessary when completions are requested next
+                        # to special characters.
+                        start_position = end_position
+                    elif current_text.endswith('.') and len(current_text) > 1:
+                        # This inserts completions for files or directories
+                        # that start with a dot
+                        start_position = end_position - 1
+                    elif current_text == '.':
+                        # This is needed if users are asking for file
+                        # completions to the right of a dot when some of its
+                        # name is part of the completed text
+                        cursor_1 = self.textCursor()
+                        found_start = False
+
+                        # Select text backwards until we find where the file
+                        # name starts
+                        while not found_start:
+                            cursor_1.movePosition(
+                                QTextCursor.PreviousCharacter,
+                                QTextCursor.KeepAnchor,
+                            )
+
+                            selection = str(cursor_1.selectedText())
+                            if text.startswith(selection):
+                                found_start = True
+
+                        current_text = str(cursor_1.selectedText())
+                        start_position = cursor_1.selectionStart()
+                        end_position = cursor_1.selectionEnd()
+
+                if not is_auto_completion_character:
+                    # Check if the completion position is in the expected range
+                    if not (
+                        start_position <= completion_position <= end_position
+                    ):
+                        return
+                    cursor.setPosition(start_position)
+
+                    # Remove the word under the cursor
+                    cursor.setPosition(end_position, QTextCursor.KeepAnchor)
+                else:
+                    # Check if we are in the correct position
+                    if cursor.position() != completion_position:
+                        return
             else:
                 # Check if we are in the correct position
                 if cursor.position() != completion_position:
@@ -988,7 +1037,6 @@ class TextEditBaseWidget(QPlainTextEdit, BaseEditMixin):
             self.insert_text(text)
         else:
             self.sig_insert_completion.emit(text)
-            self.document_did_change()
 
     def is_completion_widget_visible(self):
         """Return True is completion list widget is visible"""
@@ -1001,10 +1049,15 @@ class TextEditBaseWidget(QPlainTextEdit, BaseEditMixin):
 
     def hide_completion_widget(self, focus_to_parent=True):
         """Hide completion widget and tooltip."""
-        self.completion_widget.hide(focus_to_parent=focus_to_parent)
+        # This is necessary to catch an error when creating new editor windows.
+        # Fixes spyder-ide/spyder#19109
+        try:
+            self.completion_widget.hide(focus_to_parent=focus_to_parent)
+        except RuntimeError:
+            pass
         QToolTip.hideText()
 
-    #------Standard keys
+    # ------Standard keys
     def stdkey_clear(self):
         if not self.has_selected_text():
             self.moveCursor(QTextCursor.NextCharacter, QTextCursor.KeepAnchor)
@@ -1055,19 +1108,16 @@ class TextEditBaseWidget(QPlainTextEdit, BaseEditMixin):
         else:
             self.moveCursor(QTextCursor.EndOfBlock, move_mode)
 
-    def stdkey_pageup(self):
-        pass
-
-    def stdkey_pagedown(self):
-        pass
-
-    def stdkey_escape(self):
-        pass
-
-
-    #----Qt Events
+    # ----Qt Events
     def mousePressEvent(self, event):
         """Reimplement Qt method"""
+
+        # mouse buttons for forward and backward navigation
+        if event.button() == Qt.XButton1:
+            self.sig_prev_cursor.emit()
+        elif event.button() == Qt.XButton2:
+            self.sig_next_cursor.emit()
+
         if sys.platform.startswith('openbsd') and event.button() == Qt.MidButton:
             self.calltip_widget.hide()
             self.setFocus()
