@@ -23,7 +23,6 @@ import qstylizer.style
 from qtconsole.client import QtKernelClient
 from qtpy.QtCore import Signal, Slot
 from qtpy.QtGui import QColor
-from qtpy.QtWebEngineWidgets import WEBENGINE
 from qtpy.QtWidgets import (
     QApplication, QHBoxLayout, QLabel, QMessageBox, QVBoxLayout, QWidget)
 from traitlets.config.loader import Config, load_pyconfig_files
@@ -46,11 +45,16 @@ from spyder.plugins.ipythonconsole.widgets import (
 from spyder.utils import encoding, programs, sourcecode
 from spyder.utils.misc import get_error_match, remove_backslashes
 from spyder.utils.palette import QStylePalette
-from spyder.widgets.browser import FrameWebView
 from spyder.widgets.findreplace import FindReplace
 from spyder.widgets.tabs import Tabs
 from spyder.plugins.ipythonconsole.utils.stdfile import StdFile
 
+# In case WebEngine is not available (e.g. in Conda-forge)
+try:
+    from qtpy.QtWebEngineWidgets import WEBENGINE
+except ImportError:
+    WEBENGINE = False
+
 
 # Logging
 logger = logging.getLogger(__name__)
@@ -308,7 +312,7 @@ class IPythonConsoleWidget(PluginMainWidget):
         self.enable_infowidget = True
         if plugin:
             cli_options = plugin.get_command_line_options()
-            if cli_options.no_web_widgets:
+            if cli_options.no_web_widgets or not WEBENGINE:
                 self.enable_infowidget = False
 
         # Attrs for testing
@@ -351,6 +355,8 @@ class IPythonConsoleWidget(PluginMainWidget):
 
         # Info widget
         if self.enable_infowidget:
+            from spyder.widgets.browser import FrameWebView
+
             self.infowidget = FrameWebView(self)
             if WEBENGINE:
                 self.infowidget.page().setBackgroundColor(
@@ -1386,9 +1392,9 @@ class IPythonConsoleWidget(PluginMainWidget):
             import subprocess
             versions = {}
             pyexec = self.get_conf('executable', section='main_interpreter')
-            py_cmd = u'%s -c "import sys; print(sys.version)"' % pyexec
+            py_cmd = '"%s" -c "import sys; print(sys.version)"' % pyexec
             ipy_cmd = (
-                u'%s -c "import IPython.core.release as r; print(r.version)"'
+                '%s -c "import IPython.core.release as r; print(r.version)"'
                 % pyexec
             )
             for cmd in [py_cmd, ipy_cmd]:
